@@ -289,20 +289,18 @@ StatCompareMeans<- ggproto("StatCompareMeans", Stat,
       res <- grepl(pattern = "p\\.signif", .label)
     }
   }
-  print(res)
   return(res)
 }
 
 # Update mapping with label
 .update_mapping <- function (mapping, label){
-
   allowed.label <- list(
-    "p.signif" = quote(after_stat(p.signif)),
-    "..p.signif.." = quote(after_stat(p.signif)),
-    "p.format" = quote(after_stat(paste0("p = ", p.format))),
-    "..p.format.." = quote(after_stat(paste0("p = ", p.format))),
-    "p" = quote(after_stat(paste0("p = ", p.format))),
-    "..p.." = quote(after_stat(paste0("p = ", p.format)))
+    "p.signif" = quote(ggplot2::after_stat(p.signif)),
+    "..p.signif.." = quote(ggplot2::after_stat(p.signif)),
+    "p.format" = quote(ggplot2::after_stat(paste0("p = ", p.format))),
+    "..p.format.." = quote(ggplot2::after_stat(paste0("p = ", p.format))),
+    "p" = quote(ggplot2::after_stat(paste0("p = ", p.format))),
+    "..p.." = quote(ggplot2::after_stat(paste0("p = ", p.format)))
   )
 
   if(!is.null(label)){
@@ -317,7 +315,7 @@ StatCompareMeans<- ggproto("StatCompareMeans", Stat,
     mapping <- aes()
     mapping$label <- allowed.label[[label]]
   }
-  mapping
+  convert_label_dotdot_notation_to_after_stat(mapping)
 }
 
 # Hide NS in map_signif_level
@@ -333,23 +331,21 @@ StatCompareMeans<- ggproto("StatCompareMeans", Stat,
 # The dot-dot notation (`..p.signif..`) was deprecated in ggplot2 3.4.0.
 # after_stat(p.signif) should be used. This function makes automatic
 # conversion if user specified ..p.signif..
-#
-# NOT USED FUNCTION
 convert_label_dotdot_notation_to_after_stat <- function(mapping){
   if(!is.null(mapping) ){
     label <- mapping$label
     if(!is.null(mapping$label)){
       label <-  rlang::as_label(mapping$label)
       label <- gsub(
-        pattern = "..p.signif..", replacement = "after_stat(p.signif)",
+        pattern = "..p.signif..", replacement = "ggplot2::after_stat(p.signif)",
         x = label, fixed = TRUE
         )
       label <- gsub(
-        pattern = "..p.format..", replacement = "after_stat(p.format)",
+        pattern = "..p.format..", replacement = "ggplot2::after_stat(p.format)",
         x = label, fixed = TRUE
       )
       label <- gsub(
-        pattern = "..p..", replacement = "after_stat(p)",
+        pattern = "..p..", replacement = "ggplot2::after_stat(p)",
         x = label, fixed = TRUE
       )
       mapping$label <- parse(text = label)[[1]]
